"""Fixes and modifications related to mne-python

Contains code from MNE-Python governed by the following license (3-Clause BSD):


Copyright (C) 2011-2014, authors of MNE-Python
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the names of MNE-Python authors nor the names of any
      contributors may be used to endorse or promote products derived from
      this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""
# import this first for a chance to reverse mne's non-standard logging practice
from ._logging import CaptureLog, reset_logger

from ._dss import dss
from ._freesurfer import rename_mri
from ._interpolation import _interpolate_bads_eeg, _interpolate_bads_meg
from ._label import write_labels_to_annot
from ._types import MNE_EPOCHS, MNE_EVOKED, MNE_RAW, MNE_LABEL, MNE_VOLUME_STC



# Author: Christian Brodbeck <christianbrodbeck@nyu.edu>
from pathlib import Path

import pytest

from eelbrain import load


def test_read_cnd():
    data_root = Path('~/Data/CND').expanduser()
    if not data_root.exists():
        pytest.skip(f"Data not available at {data_root}")
